@@ -38,7 +38,7 @@ class DivisionsHandler:
     def filter_to_source(self, source_id: Union[str, UUID]) -> 'DivisionsHandler':
         search_uuid = source_id if isinstance(source_id, UUID) else UUID(source_id)
         return DivisionsHandler(
-            divs={k: v for k, v in self._divs.items() if source_id in search_uuid}
+            divs={k: v for k, v in self._divs.items() if search_uuid in v}
         )
 
     def get_sources_for_division(self, div: Division) -> List[UUID]:
