@@ -36,7 +36,7 @@ class FriendCodeHandler:
     def filter_to_source(self, source_id: Union[str, UUID]) -> 'FriendCodeHandler':
         search_uuid = source_id if isinstance(source_id, UUID) else UUID(source_id)
         return FriendCodeHandler(
-            codes={k: v for k, v in self._codes.items() if source_id in search_uuid}
+            codes={k: v for k, v in self._codes.items() if search_uuid in v}
         )
 
     def get_sources_for_code(self, fc: FriendCode) -> List[UUID]:
