@@ -126,7 +126,7 @@ class Team:
             battlefy_persistent_team_ids=from_list(lambda x: BattlefyTeamSocial.from_dict(x),
                                                    obj.get("BattlefyPersistentTeamIds")),
             clan_tags=from_list(lambda x: ClanTag.from_dict(x), obj.get("ClanTags")),
-            division_information=DivisionsHandler.from_dict(obj.get("Divisions")),
+            division_information=DivisionsHandler.from_dict(obj.get("Divisions")) if "Divisions" in obj else None,
             names=from_list(lambda x: Name.from_dict(x), obj.get("N")),
             twitter_profiles=from_list(lambda x: Twitter.from_dict(x), obj.get("Twitter")),
             guid=UUID(obj.get("Id"))
