@@ -18,7 +18,7 @@ class SlappResponseObject:
         placements_for_players: Dict[str, Dict[str, List[Bracket]]] = {}
         """Dictionary keyed by Player id, of value Dictionary keyed by Source id of value Placements list"""
 
-        for team_id, team_dict in response.get("AdditionalTeams").items():
+        for team_id, team_dict in response.get("AdditionalTeams", {}).items():
             known_teams[team_id.__str__()] = Team.from_dict(team_dict)
         for team in matched_teams:
             known_teams[team.guid.__str__()] = team
@@ -27,7 +27,7 @@ class SlappResponseObject:
         # The tuple is sent as a dict, which is keyed by Item1, Item2, and contains the Player (Item1) or bool (Item2).
         matched_players_for_teams: Dict[str, List[Tuple[Player, bool]]] = dict()
         """Dictionary keyed by Team id, of value (Player, bool)[], where the bool is if the Player is currently in the team."""
-        for team_id, player_tuples in response.get("PlayersForTeams").items():
+        for team_id, player_tuples in response.get("PlayersForTeams", {}).items():
             for tup in player_tuples:
                 player_dict = tup.get("Item1", None)
                 if isinstance(player_dict, dict):
@@ -36,10 +36,10 @@ class SlappResponseObject:
                         .append((Player.from_dict(player_dict), bool(tup.get("Item2", False))))
 
         sources: Dict[str, SimpleSource] = {}
-        for source_id, source_name in response.get("Sources").items():
+        for source_id, source_name in response.get("Sources", {}).items():
             sources[source_id] = SimpleSource(id=source_id, name=source_name)
 
-        for player_id, source_dicts in response.get("PlacementsForPlayers").items():
+        for player_id, source_dicts in response.get("PlacementsForPlayers", {}).items():
             for source_id, brackets in source_dicts.items():
                 for bracket in brackets:
                     placements_for_players\
